import React from 'react'
import { createJBrowseTheme } from '@jbrowse/core/ui'
import { createTestSession } from '@jbrowse/web/src/rootModel'
import { render } from '@testing-library/react'
import { ThemeProvider } from '@mui/material/styles'

// locals
import HierarchicalTrackSelector from './HierarchicalTrackSelector'

jest.mock('@jbrowse/web/src/makeWorkerInstance', () => () => {})

// @ts-ignore
window.requestIdleCallback = cb => cb()
window.cancelIdleCallback = () => {}

test('renders nothing with no assembly', () => {
  const session = createTestSession()
  const firstView = session.addView('LinearGenomeView')
  const model = firstView.activateTrackSelector()

  const { container } = render(
    <ThemeProvider theme={createJBrowseTheme()}>
      {/* @ts-ignore*/}
      <HierarchicalTrackSelector model={model} />
    </ThemeProvider>,
  )
  expect(container.firstChild).toMatchSnapshot()
})

test('renders with a couple of uncategorized tracks', async () => {
  const session = createTestSession()
  session.addAssemblyConf({
    name: 'volMyt1',
    sequence: {
      trackId: 'sequenceConfigId',
      type: 'ReferenceSequenceTrack',
      adapter: {
        type: 'FromConfigSequenceAdapter',
        features: [
          {
            refName: 'ctgA',
            uniqueId: 'firstId',
            start: 0,
            end: 10,
            seq: 'cattgttgcg',
          },
        ],
      },
    },
  })
  session.addTrackConf({
    trackId: 'fooC',
    assemblyNames: ['volMyt1'],
    type: 'FeatureTrack',
    adapter: { type: 'FromConfigAdapter', features: [] },
  })
  session.addTrackConf({
    trackId: 'barC',
    assemblyNames: ['volMyt1'],
    type: 'FeatureTrack',
    adapter: { type: 'FromConfigAdapter', features: [] },
  })
  const firstView = session.addView('LinearGenomeView', {
    displayedRegions: [
      {
        assemblyName: 'volMyt1',
        refName: 'ctgA',
        start: 0,
        end: 1000,
      },
    ],
  })
  firstView.showTrack(session.sessionTracks[0].trackId)
  firstView.showTrack(session.sessionTracks[1].trackId)
  const model = firstView.activateTrackSelector()

  const { container, findByTestId } = render(
    <ThemeProvider theme={createJBrowseTheme()}>
      {/* @ts-ignore*/}
      <HierarchicalTrackSelector model={model} />
    </ThemeProvider>,
  )
  await findByTestId('hierarchical_track_selector')
  expect(container.firstChild).toMatchSnapshot()
})

test('renders with a couple of categorized tracks', async () => {
  const session = createTestSession()
  session.addAssemblyConf({
    name: 'volMyt1',
    sequence: {
      trackId: 'sequenceConfigId',
      type: 'ReferenceSequenceTrack',
      adapter: {
        type: 'FromConfigSequenceAdapter',
        features: [
          {
            refName: 'ctgA',
            uniqueId: 'firstId',
            start: 0,
            end: 10,
            seq: 'cattgttgcg',
          },
        ],
      },
    },
  })

  session.addTrackConf({
    trackId: 'fooC',
    assemblyNames: ['volMyt1'],
    type: 'FeatureTrack',
    adapter: { type: 'FromConfigAdapter', features: [] },
  })
  session.addTrackConf({
    trackId: 'barC',
    assemblyNames: ['volMyt1'],
    type: 'FeatureTrack',
    adapter: { type: 'FromConfigAdapter', features: [] },
  })
  const firstView = session.addView('LinearGenomeView', {
    displayedRegions: [
      {
        assemblyName: 'volMyt1',
        refName: 'ctgA',
        start: 0,
        end: 1000,
      },
    ],
  })
  firstView.showTrack(session.sessionTracks[0].trackId)
  firstView.showTrack(session.sessionTracks[1].trackId)
  firstView.tracks[0].configuration.category.set(['Foo Category'])
  firstView.tracks[1].configuration.category.set([
    'Foo Category',
    'Bar Category',
  ])
  const model = firstView.activateTrackSelector()

  const { container, findByTestId } = render(
    <ThemeProvider theme={createJBrowseTheme()}>
      {/* @ts-ignore*/}
      <HierarchicalTrackSelector model={model} />
    </ThemeProvider>,
  )
  await findByTestId('hierarchical_track_selector')
  expect(container.firstChild).toMatchSnapshot()
})
