---
title: v1.7.10 Release
date: 2022-06-13 23:34:41
tags: ['release', 'jbrowse 2']
---

We are pleased to present the latest JBrowse 2 release!

This has some great new features including

- Feature detail formatters - add callback to add links or other customizations
  to the feature details panels (see
  https://jbrowse.org/jb2/docs/config_guide/#customizing-feature-details-panels
  for more info)
- Session URL formats for loading spreadsheet, SV inspector, and linear and
  dotplot synteny views (see https://jbrowse.org/jb2/docs/urlparams/ for
  details)
- You can enter "chr1 100 200" to navigate to "chr1:100-200" as a simple way to
  copy from a bed file or similar

### Feature detail formatter

Here is an example which adds a link to the "Name" panel in the feature details.
It uses the jexl callback that returns an object with keys for each field to
modify (e.g. the key name is used here). See

```json
{
  "type": "FeatureTrack",
  "trackId": "ncbi_gff_hg19_2",
  "name": "NCBI RefSeq",
  "formatDetails": {
    "feature": "jexl:{name:'<a href=https://google.com/?q='+feature.name+'>'+feature.name+'</a>'}"
  },
  "assemblyNames": ["hg19"],
  "adapter": {
    "type": "Gff3TabixAdapter",
    "gffGzLocation": {
      "uri": "https://s3.amazonaws.com/jbrowse.org/genomes/hg19/ncbi_refseq/GRCh37_latest_genomic.sort.gff.gz"
    },
    "index": {
      "location": {
        "uri": "https://s3.amazonaws.com/jbrowse.org/genomes/hg19/ncbi_refseq/GRCh37_latest_genomic.sort.gff.gz.tbi"
      }
    }
  }
}
```

Example screenshot

![](https://user-images.githubusercontent.com/6511937/173461279-1afebb28-5928-47c1-8157-ecd2427a7fb2.png)

See
https://jbrowse.org/jb2/docs/config_guide/#customizing-feature-details-panels
for more info

### Clearer configuration panel with explicit "Add item" button with "OK"/"Cancel" to confirm

![](https://user-images.githubusercontent.com/6511937/172203086-bf99e089-192a-46a6-baf1-96b3f97a36f2.png)

### Large track menus no longer disappear off the screen

Before

![](https://user-images.githubusercontent.com/6511937/172012588-b82cace7-6c0c-4de8-991e-d1bc9ce17a77.png)

After

![](https://user-images.githubusercontent.com/6511937/172013123-0117cc8d-7008-408a-978a-72ccb4aec7da.png)

### Automatically generate clickable links for data files in About track dialog

![](https://user-images.githubusercontent.com/6511937/172653136-720e48f9-2e9f-494b-8dda-a1708e74d089.png)

See also the "Copy config" button to download the config

## Downloads

- [v1.7.10](https://github.com/GMOD/jbrowse-components/releases/tag/v1.7.10)

To install JBrowse 2 for the web, you can download the link above, or you can
use the JBrowse CLI to automatically download the latest version. See the
[JBrowse web quick start](https://jbrowse.org/jb2/docs/quickstart_web) for more
details.

See "Packages in this release" in the changelog for links to packages published
on NPM.

## 1.7.10 (2022-06-13)

<details><summary>Packages in this release</summary>
<p>

| Package                                 | Download                                                          |
| --------------------------------------- | ----------------------------------------------------------------- |
| @jbrowse/core                           | https://www.npmjs.com/package/@jbrowse/core                       |
| @jbrowse/plugin-alignments              | https://www.npmjs.com/package/@jbrowse/plugin-alignments          |
| @jbrowse/plugin-authentication          |                                                                   |
| @jbrowse/plugin-breakpoint-split-view   |                                                                   |
| @jbrowse/plugin-config                  | https://www.npmjs.com/package/@jbrowse/plugin-config              |
| @jbrowse/plugin-data-management         | https://www.npmjs.com/package/@jbrowse/plugin-data-management     |
| @jbrowse/plugin-dotplot-view            |                                                                   |
| @jbrowse/plugin-linear-comparative-view |                                                                   |
| @jbrowse/plugin-linear-genome-view      | https://www.npmjs.com/package/@jbrowse/plugin-linear-genome-view  |
| @jbrowse/plugin-spreadsheet-view        |                                                                   |
| @jbrowse/plugin-sv-inspector            |                                                                   |
| @jbrowse/plugin-variants                | https://www.npmjs.com/package/@jbrowse/plugin-variants            |
| @jbrowse/plugin-wiggle                  | https://www.npmjs.com/package/@jbrowse/plugin-wiggle              |
| @jbrowse/cli                            | https://www.npmjs.com/package/@jbrowse/cli                        |
| @jbrowse/desktop                        |                                                                   |
| @jbrowse/img                            | https://www.npmjs.com/package/@jbrowse/img                        |
| jbrowse-predefined-sessions             |                                                                   |
| @jbrowse/react-circular-genome-view     | https://www.npmjs.com/package/@jbrowse/react-circular-genome-view |
| @jbrowse/react-linear-genome-view       | https://www.npmjs.com/package/@jbrowse/react-linear-genome-view   |
| @jbrowse/web                            |                                                                   |

</p>
</details>

#### :rocket: Enhancement

- Other
  - [#3025](https://github.com/GMOD/jbrowse-components/pull/3025) Add dotplot
    session spec ([@cmdcolin](https://github.com/cmdcolin))
  - [#2975](https://github.com/GMOD/jbrowse-components/pull/2975) Add simplified
    URL format for loading synteny views
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#3023](https://github.com/GMOD/jbrowse-components/pull/3023) Add error
    handling in case of invalid OAuth2 configuration used.
    ([@andrzejgrzelak](https://github.com/andrzejgrzelak))
  - [#3020](https://github.com/GMOD/jbrowse-components/pull/3020) Allow choosing
    trackId when using text-index with --file with --fileId
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#3016](https://github.com/GMOD/jbrowse-components/pull/3016) Allow
    whitespace separated refname,start,end type locstring
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#3006](https://github.com/GMOD/jbrowse-components/pull/3006) Add string
    array configuration slot UI improvements
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#2998](https://github.com/GMOD/jbrowse-components/pull/2998) Avoid
    rendering offscreen contents in pileup renderer
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#3000](https://github.com/GMOD/jbrowse-components/pull/3000) Add reference
    base and correct percentage calculations to tooltip on SNPCoverage display
    ([@cmdcolin](https://github.com/cmdcolin))
- `core`
  - [#2981](https://github.com/GMOD/jbrowse-components/pull/2981) Add simplified
    URL format for loading spreadsheet and SV inspector
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#2990](https://github.com/GMOD/jbrowse-components/pull/2990) Use shortened
    megabases (M) display when zoomed out, and option to hide the "open track
    selector" button
    ([@carolinebridge-oicr](https://github.com/carolinebridge-oicr))
  - [#3003](https://github.com/GMOD/jbrowse-components/pull/3003) Add ability to
    run field formatters on the feature details panel
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#3017](https://github.com/GMOD/jbrowse-components/pull/3017) Add button to
    copy track config in About track dialog
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#2999](https://github.com/GMOD/jbrowse-components/pull/2999) Generate
    clickable links to track data in about track dialog
    ([@cmdcolin](https://github.com/cmdcolin))
- `__mocks__`, `core`
  - [#3005](https://github.com/GMOD/jbrowse-components/pull/3005) Use cascading
    menu helper library for track menu to avoid menu going offscreen
    ([@cmdcolin](https://github.com/cmdcolin))

#### :bug: Bug Fix

- Other
  - [#3021](https://github.com/GMOD/jbrowse-components/pull/3021) Fix mouseover
    display of read name to alignments track
    ([@cmdcolin](https://github.com/cmdcolin))
  - [#3012](https://github.com/GMOD/jbrowse-components/pull/3012) Small fix to
    rankSearchResults logic ([@cmdcolin](https://github.com/cmdcolin))
  - [#3009](https://github.com/GMOD/jbrowse-components/pull/3009) Add jsdom to
    jbrowse-img to fix --noRasterize option
    ([@cmdcolin](https://github.com/cmdcolin))
- `core`
  - [#3007](https://github.com/GMOD/jbrowse-components/pull/3007) Fix read vs
    ref dotplot view ([@cmdcolin](https://github.com/cmdcolin))

#### Committers: 3

- Caroline Bridge
  ([@carolinebridge-oicr](https://github.com/carolinebridge-oicr))
- Colin Diesh ([@cmdcolin](https://github.com/cmdcolin))
- [@andrzejgrzelak](https://github.com/andrzejgrzelak)
